@@ -28,7 +28,8 @@ def read_input(geojson_dict: dict):
         for x in data.features
     ]
     config = InputConfig(data.properties.ordered_colours,
-                         data.properties.buffer_size)
+                         data.properties.buffer_size,
+                         data.properties.opposite_share_thickness)
 
     check_colours(polygons_and_colours, config.colour_order)
 
